@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007004";
+    our $MITE_VERSION = "0.007005";
 
     BEGIN {
         require Scalar::Util;
@@ -37,30 +37,16 @@
 
         # Attribute app (type: Object)
         croak "Missing key in constructor: app" unless exists $args->{"app"};
-        (
-            do {
-
-                package Mite::Shim;
-                use Scalar::Util ();
-                Scalar::Util::blessed( $args->{"app"} );
-            }
-          )
+        blessed( $args->{"app"} )
           or croak "Type check failed in constructor: %s should be %s", "app",
           "Object";
         $self->{"app"} = $args->{"app"};
         require Scalar::Util && Scalar::Util::weaken( $self->{"app"} )
-          if exists $self->{"app"};
+          if ref $self->{"app"};
 
         # Attribute kingpin_command (type: Object)
         if ( exists $args->{"kingpin_command"} ) {
-            (
-                do {
-
-                    package Mite::Shim;
-                    use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{"kingpin_command"} );
-                }
-              )
+            blessed( $args->{"kingpin_command"} )
               or croak "Type check failed in constructor: %s should be %s",
               "kingpin_command", "Object";
             $self->{"kingpin_command"} = $args->{"kingpin_command"};
@@ -178,14 +164,7 @@
             exists( $_[0]{"kingpin_command"} ) ? $_[0]{"kingpin_command"} : (
                 $_[0]{"kingpin_command"} = do {
                     my $default_value = $_[0]->_build_kingpin_command;
-                    (
-                        do {
-
-                            package Mite::Shim;
-                            use Scalar::Util ();
-                            Scalar::Util::blessed($default_value);
-                        }
-                      )
+                    blessed($default_value)
                       or croak( "Type check failed in default: %s should be %s",
                         "kingpin_command", "Object" );
                     $default_value;
