@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007004';
+our $VERSION   = '0.007005';
 
 use B ();
 
@@ -409,6 +409,26 @@ sub has_simple_default {
     return !ref $self->default;
 }
 
+sub _compile_check {
+    my ( $self, $varname ) = @_;
+
+    my $type = $self->type;
+
+    if ( $self->compiling_class
+    and  $self->compiling_class->imported_functions->{blessed} ) {
+        if ( $type == Object ) {
+            return "blessed( $varname )";
+        }
+        elsif ( $type->isa( 'Type::Tiny::Class' ) ) {
+            return sprintf 'blessed( %s ) && %s->isa( %s )',
+                $varname, $varname, $self->_q( $type->class );
+        }
+    }
+
+    local $Type::Tiny::AvoidCallbacks = 1;
+    return $type->inline_check( $varname );
+}
+
 sub _compile_coercion {
     my ( $self, $expression ) = @_;
     if ( $self->coerce and my $type = $self->type ) {
@@ -425,20 +445,21 @@ sub _compile_checked_default {
     my $default = $self->_compile_default( $selfvar );
     my $type = $self->type or return $default;
 
-    local $Type::Tiny::AvoidCallbacks = 1;
-
     if ( $self->coerce ) {
         $default = $self->_compile_coercion( $default );
     }
 
     return sprintf 'do { my $default_value = %s; %s or %s( "Type check failed in default: %%s should be %%s", %s, %s ); $default_value }',
-        $default, $type->inline_check('$default_value'), $self->_function_for_croak, $self->_q($self->name), $self->_q($type->display_name);
+        $default, $self->_compile_check('$default_value'), $self->_function_for_croak, $self->_q($self->name), $self->_q($type->display_name);
 }
 
 sub _compile_default {
     my ( $self, $selfvar ) = @_;
 
-    if ( $self->has_coderef_default ) {
+    if ( $self->has_builder ) {
+        return sprintf '%s->%s', $selfvar, $self->_expand_name( $self->builder );
+    }
+    elsif ( $self->has_coderef_default ) {
         my $var = $self->coderef_default_variable;
         return sprintf '%s->( %s )', $var, $selfvar;
     }
@@ -448,12 +469,14 @@ sub _compile_default {
     elsif ( $self->has_reference_default ) {
         return HashRef->check( $self->default ) ? '{}' : '[]';
     }
+    elsif ( $self->has_simple_default and $self->type and $self->type == Bool ) {
+        my $truthy = $self->compiling_class->imported_functions->{true}  ? 'true'  : '!!1';
+        my $falsey = $self->compiling_class->imported_functions->{false} ? 'false' : '!!0';
+        return $self->default ? $truthy : $falsey;
+    }
     elsif ( $self->has_simple_default ) {
         return defined( $self->default ) ? $self->_q( $self->default ) : 'undef';
     }
-    elsif ( $self->has_builder ) {
-        return sprintf '%s->%s', $selfvar, $self->_expand_name( $self->builder );
-    }
 
     # should never get here
     return 'undef';
@@ -552,8 +575,6 @@ sub compile_init {
         }
 
         if ( my $type = $self->type ) {
-            local $Type::Tiny::AvoidCallbacks = 1;
-            
             if ( $self->coerce ) {
                 $code .= sprintf 'do { my $coerced_value = %s; ', $self->_compile_coercion( $valuevar );
                 $valuevar = '$coerced_value';
@@ -561,7 +582,7 @@ sub compile_init {
             }
 
             $code .= sprintf '%s or %s "Type check failed in constructor: %%s should be %%s", %s, %s; ',
-                $type->inline_check( $valuevar ),
+                $self->_compile_check( $valuevar ),
                 $self->_function_for_croak,
                 $self->_q_init_arg,
                 $self->_q( $type->display_name );
@@ -583,7 +604,7 @@ sub compile_init {
     }
 
     if ( $self->weak_ref ) {
-        push @code, sprintf 'require Scalar::Util && Scalar::Util::weaken(%s->{%s}) if exists %s->{%s};',
+        push @code, sprintf 'require Scalar::Util && Scalar::Util::weaken(%s->{%s}) if ref %s->{%s};',
             $selfvar, $self->_q_name, $selfvar, $self->_q_name;
     }
 
@@ -634,13 +655,12 @@ my %code_template;
         }
         my $valuevar = '$_[1]';
         if ( my $type = $self->type ) {
-            local $Type::Tiny::AvoidCallbacks = 1;
             if ( $self->coerce ) {
                 $code .= sprintf 'my $value = %s; ', $self->_compile_coercion($valuevar);
                 $valuevar = '$value';
             }
             $code .= sprintf '%s or %s( "Type check failed in %%s: value should be %%s", %s, %s ); ',
-                $type->inline_check($valuevar), $self->_function_for_croak, $self->_q( $arg{label} // 'writer' ), $self->_q( $type->display_name );
+                $self->_compile_check($valuevar), $self->_function_for_croak, $self->_q( $arg{label} // 'writer' ), $self->_q( $type->display_name );
         }
         if ( $self->clone_on_write ) {
             $code .= sprintf 'my $cloned = %s; ',
@@ -658,8 +678,8 @@ my %code_template;
             ) . '; ';
         }
         if ( $self->weak_ref ) {
-            $code .= sprintf 'require Scalar::Util && Scalar::Util::weaken($_[0]{%s}); ',
-                $self->_q_name;
+            $code .= sprintf 'require Scalar::Util && Scalar::Util::weaken($_[0]{%s}) if ref $_[0]{%s}; ',
+                $self->_q_name, $self->_q_name;
         }
         $code .= '$_[0];';
         return $code;
