@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007004";
+    our $MITE_VERSION = "0.007005";
 
     BEGIN {
         require Scalar::Util;
@@ -113,7 +113,7 @@
 
         # Attribute debug (type: Bool)
         do {
-            my $value = exists( $args->{"debug"} ) ? $args->{"debug"} : "";
+            my $value = exists( $args->{"debug"} ) ? $args->{"debug"} : false;
             (
                 !ref $value
                   and (!defined $value
