@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007004";
+    our $MITE_VERSION = "0.007005";
 
     BEGIN {
         require Scalar::Util;
@@ -49,7 +49,7 @@
             $self->{"class"} = $args->{"class"};
         }
         require Scalar::Util && Scalar::Util::weaken( $self->{"class"} )
-          if exists $self->{"class"};
+          if ref $self->{"class"};
 
         # Attribute method_name (type: Str)
         croak "Missing key in constructor: method_name"
@@ -94,7 +94,7 @@
 
         # Attribute method (type: Bool)
         do {
-            my $value = exists( $args->{"method"} ) ? $args->{"method"} : "1";
+            my $value = exists( $args->{"method"} ) ? $args->{"method"} : true;
             (
                 !ref $value
                   and (!defined $value
@@ -278,14 +278,7 @@
                 exists( $_[0]{"compiler"} ) ? $_[0]{"compiler"} : (
                     $_[0]{"compiler"} = do {
                         my $default_value = $_[0]->_build_compiler;
-                        (
-                            do {
-
-                                package Mite::Shim;
-                                use Scalar::Util ();
-                                Scalar::Util::blessed($default_value);
-                            }
-                          )
+                        blessed($default_value)
                           or croak(
                             "Type check failed in default: %s should be %s",
                             "compiler", "Object" );
@@ -305,14 +298,7 @@
             exists( $_[0]{"compiler"} ) ? $_[0]{"compiler"} : (
                 $_[0]{"compiler"} = do {
                     my $default_value = $_[0]->_build_compiler;
-                    (
-                        do {
-
-                            package Mite::Shim;
-                            use Scalar::Util ();
-                            Scalar::Util::blessed($default_value);
-                        }
-                      )
+                    blessed($default_value)
                       or croak( "Type check failed in default: %s should be %s",
                         "compiler", "Object" );
                     $default_value;
