@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007004";
+    our $MITE_VERSION = "0.007005";
 
     BEGIN {
         require Scalar::Util;
@@ -84,13 +84,7 @@
                   )
                   : $to_coerce;
             };
-            (
-                do {
-                    use Scalar::Util ();
-                    Scalar::Util::blessed($coerced_value)
-                      and $coerced_value->isa(q[Path::Tiny]);
-                }
-              )
+            blessed($coerced_value) && $coerced_value->isa("Path::Tiny")
               or croak "Type check failed in constructor: %s should be %s",
               "file", "Path";
             $self->{"file"} = $coerced_value;
@@ -189,7 +183,7 @@
             $self->{"project"} = $args->{"project"};
         }
         require Scalar::Util && Scalar::Util::weaken( $self->{"project"} )
-          if exists $self->{"project"};
+          if ref $self->{"project"};
 
         # Call BUILD methods
         $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
@@ -354,7 +348,8 @@
               or croak( "Type check failed in %s: value should be %s",
                 "accessor", "Mite::Project" );
             $_[0]{"project"} = $_[1];
-            require Scalar::Util && Scalar::Util::weaken( $_[0]{"project"} );
+            require Scalar::Util && Scalar::Util::weaken( $_[0]{"project"} )
+              if ref $_[0]{"project"};
             $_[0];
           }
           : ( $_[0]{"project"} );
